@@ -142,9 +142,12 @@
 #include "gcorba.h"
 #include "gmain.h"
 #include "gsession.h"
+#ifdef HAVE_GNOME_WINDOW_ICON
+#    include <libgnomeui/gnome-window-icon.h>
+#endif
 #endif
 
-/* "$Id: main.c,v 1.112 2000/05/09 01:18:30 miguel Exp $" */
+/* "$Id: main.c,v 1.113 2000/06/20 19:50:32 jberkman Exp $" */
 
 /* When the modes are active, left_panel, right_panel and tree_panel */
 /* Point to a proper data structure.  You should check with the functions */
@@ -2844,9 +2847,12 @@ handle_args (int argc, char *argv [])
     init_corba_with_args (&argc, argv, &ctx);
 #else
     gnome_init_with_popt_table ("gmc", VERSION, argc, argv, argument_table, 0, &ctx);
-#endif
     maybe_display_linksdir ();
+#endif
 
+#ifdef HAVE_GNOME_WINDOW_ICON
+    gnome_window_icon_set_default_from_file (ICONDIR"/i-directory.png");
+#endif
     gtk_widget_push_visual (gdk_imlib_get_visual ());
     gtk_widget_push_colormap (gdk_imlib_get_colormap ());
 	
