@@ -102,7 +102,7 @@ typedef struct {
     int      count;		/* Number of files in dir structure */
     int      marked;		/* Count of marked files */
     int      dirs_marked;	/* Count of marked directories */
-    long int total;		/* Bytes in marked files */
+    double   total;		/* Bytes in marked files */
     int      top_file;		/* The file showed on the top of the panel */
     int      selected;		/* Index to the selected file */
     int      reverse;		/* Show listing in reverse? */
@@ -219,6 +219,9 @@ extern int panel_scroll_pages;
 #define selection(p) (&(p->dir.list [p->selected]))
 #ifdef HAVE_GNOME
 #define is_a_desktop_panel(p) ((p->is_a_desktop_panel))
+/* Evil empty trash_hack */
+extern int is_trash_panel;
+
 #else
 #define is_a_desktop_panel(p) FALSE
 #endif
