@@ -70,7 +70,7 @@ extern int we_can_afford_the_speed;
 int use_magic = 0;
 #endif
 
-/* "$Id: setup.c,v 1.36 2000/02/11 00:33:28 pavel Exp $" */
+/* "$Id: setup.c,v 1.37 2000/04/14 01:19:58 timur Exp $" */
 
 #ifdef USE_VFS
 extern int vfs_timeout;
@@ -527,10 +527,10 @@ load_mode (char *section)
 static char *
 do_load_string (char *s, char *ss, char *def)
 {
-    char *buffer = g_malloc (128);
+    char *buffer = g_malloc (BUF_SMALL);
     char *p;
 
-    load_string (s, ss, def, buffer, 128);
+    load_string (s, ss, def, buffer, BUF_SMALL);
 
     p = g_strdup (buffer);
     g_free (buffer);
