@@ -43,11 +43,15 @@ char *default_edition_colors =
 "gauge=white,black:"
 "input=black,cyan:"
 "directory=white,blue:"
-"execute=brightgreen,blue:"
+"executable=brightgreen,blue:"
 "link=lightgray,blue:"
+"stalledlink=brightred,blue:"
 "device=brightmagenta,blue:"
 "core=red,blue:"
-"special=black,blue";
+"special=black,blue:"
+"editnormal=lightgray,blue:"
+"editbold=yellow,blue:"
+"editmarked=black,cyan";
 
 void
 edition_post_exec (void)
