@@ -5,7 +5,7 @@
                1995 Jakub Jelinek
 	       1998 Pavel Machek
    
-   $Id: vfs.c,v 1.59 2000/05/16 14:59:33 pavel Exp $
+   $Id: vfs.c,v 1.60 2000/05/25 14:47:48 pavel Exp $
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
@@ -1064,12 +1064,12 @@ mc_def_getlocalcopy (vfs *vfs, char *filename)
     fdout = open (tmp, O_CREAT|O_WRONLY|O_TRUNC|O_EXCL, 0600);
     if (fdout == -1)
 	goto fail;
-    while ((i = mc_read (fdin, buffer, sizeof (buffer))) > 0)
-        write (fdout, buffer, i);
+    while ((i = mc_read (fdin, buffer, sizeof (buffer))) > 0){
+	if (write (fdout, buffer, i) != i)
+	    goto fail;
+    }
     if (i == -1)
 	goto fail;
-    if (write (fdout, buffer, i)==-1)
-	goto fail;
     i = mc_close (fdin);
     fdin = -1;
     if (i==-1)
@@ -1117,15 +1117,13 @@ mc_def_ungetlocalcopy (vfs *vfs, char *filename, char *local, int has_changed)
         fdout = mc_open (filename, O_WRONLY | O_TRUNC);
         if (fdout == -1)
 	    goto failed;
-        while ((i = read (fdin, buffer, sizeof (buffer))) == sizeof (buffer)){
-            mc_write (fdout, buffer, i);
-        }
+	while ((i = read (fdin, buffer, sizeof (buffer))) > 0){
+	    if (mc_write (fdout, buffer, i) != i)
+		goto failed;
+	}
 	if (i == -1)
 	    goto failed;
 
-	if (mc_write (fdout, buffer, i) == -1)
-	    goto failed;
-
         if (close (fdin)==-1)
 	    goto failed;
         if (mc_close (fdout)==-1) {
@@ -1322,7 +1320,6 @@ vfs_split_text (char *p)
     char *original = p;
     int  numcols;
 
-
     for (numcols = 0; *p && numcols < MAXCOLS; numcols++){
 	while (*p == ' ' || *p == '\r' || *p == '\n'){
 	    *p = 0;
